@@ -9,56 +9,125 @@ Exported functions:
 * callLater - call a function on the main thread after a delay (async)
 """
 
-__all__ = ( 'runEventLoop', 'runConsoleEventLoop', 'stopEventLoop', 'endSheetMethod', 'callAfter', 'callLater' )
-
-from AppKit import (NSApp, NSRunAlertPanel, NSApplicationMain,
-                    NSApplicationDidFinishLaunchingNotification)
-from Foundation import (NSObject, NSRunLoop, NSTimer, NSDefaultRunLoopMode,
-                        NSNotificationCenter, NSLog, NSAutoreleasePool)
+__all__ = (
+    "runEventLoop",
+    "runConsoleEventLoop",
+    "stopEventLoop",
+    "endSheetMethod",
+    "callAfter",
+    "callLater",
+)
 
 import os
 import sys
 import traceback
+
 import objc
+from AppKit import (
+    NSApp,
+    NSApplicationDidFinishLaunchingNotification,
+    NSApplicationMain,
+    NSRunAlertPanel,
+)
+from Foundation import (
+    NSAutoreleasePool,
+    NSDate,
+    NSDefaultRunLoopMode,
+    NSLog,
+    NSNotificationCenter,
+    NSObject,
+    NSRunLoop,
+    NSThread,
+    NSTimer,
+)
+from objc import super
 
-class PyObjCAppHelperCaller(NSObject):
 
-    def initWithArgs_(self, args):
-        self = self.init()
-        self.args = args
+class PyObjCMessageRunner(NSObject):
+    """
+    Wraps a Python function and its arguments and allows it to be posted to the
+    MainThread's `NSRunLoop`.
+    """
+
+    def initWithPayload_(self, payload):
+        """
+        Designated initializer.
+        """
+        self = super(PyObjCMessageRunner, self).init()
+        if not self:
+            return None
+
+        self._payload = payload
+
         return self
 
-    def callAfter_(self, sender):
+    def callAfter(self):
+        """
+        Posts a message to the Main thread, to be executed immediately.
+        """
         self.performSelectorOnMainThread_withObject_waitUntilDone_(
-            self.call_, self.args, False)
+            self.scheduleCallWithDelay_, None, False
+        )
 
     def callLater_(self, delay):
-        self.performSelector_withObject_afterDelay_(
-            self.callAfter_, None, delay)
+        """
+        Posts a message to the Main thread, to be executed after the given
+        delay, in seconds.
+        """
+        self.performSelectorOnMainThread_withObject_waitUntilDone_(
+            self.scheduleCallWithDelay_, delay, False
+        )
 
-    def call_(self, func_args_kwargs):
-        (func, args, kwargs) = func_args_kwargs
+    def scheduleCallWithDelay_(self, delay):
+        """
+        This is run once we're on the Main thread.
+        """
+        assert NSThread.isMainThread(), "Call is not executing on the Main thread!"
+
+        # There's no delay, just run the call now.
+        if not delay:
+            self.performCall()
+            return
+
+        # There's a delay, schedule it for later.
+        self.performSelector_withObject_afterDelay_(self.performCall, None, delay)
+
+    def performCall(self):
+        """
+        Actually runs the payload.
+        """
+        assert NSThread.isMainThread(), "Call is not executing on the Main thread!"
+
+        # Unpack the payload.
+        (func, args, kwargs) = self._payload
+
+        # Run it.
         func(*args, **kwargs)
 
 
 def callAfter(func, *args, **kwargs):
-    """call a function on the main thread (async)"""
+    """
+    Call a function on the Main thread (async).
+    """
     pool = NSAutoreleasePool.alloc().init()
-    obj = PyObjCAppHelperCaller.alloc().initWithArgs_((func, args, kwargs))
-    obj.callAfter_(None)
-    del obj
+    runner = PyObjCMessageRunner.alloc().initWithPayload_((func, args, kwargs))
+    runner.callAfter()
+    del runner
     del pool
 
+
 def callLater(delay, func, *args, **kwargs):
-    """call a function on the main thread after a delay (async)"""
+    """
+    Call a function on the Main thread after a delay (async).
+    """
     pool = NSAutoreleasePool.alloc().init()
-    obj = PyObjCAppHelperCaller.alloc().initWithArgs_((func, args, kwargs))
-    obj.callLater_(delay)
-    del obj
+    runner = PyObjCMessageRunner.alloc().initWithPayload_((func, args, kwargs))
+    runner.callLater_(delay)
+    del runner
     del pool
 
-class PyObjCAppHelperApplicationActivator(NSObject):
 
+class PyObjCAppHelperApplicationActivator(NSObject):
     def activateNow_(self, aNotification):
         NSApp().activateIgnoringOtherApps_(True)
 
@@ -69,6 +138,7 @@ class PyObjCAppHelperRunLoopStopper(NSObject):
     def currentRunLoopStopper(cls):
         runLoop = NSRunLoop.currentRunLoop()
         return cls.singletons.get(runLoop)
+
     currentRunLoopStopper = classmethod(currentRunLoopStopper)
 
     def init(self):
@@ -83,12 +153,14 @@ class PyObjCAppHelperRunLoopStopper(NSObject):
         if runLoop in cls.singletons:
             raise ValueError("Stopper already registered for this runLoop")
         cls.singletons[runLoop] = runLoopStopper
+
     addRunLoopStopper_toRunLoop_ = classmethod(addRunLoopStopper_toRunLoop_)
 
     def removeRunLoopStopperFromRunLoop_(cls, runLoop):
         if runLoop not in cls.singletons:
             raise ValueError("Stopper not registered for this runLoop")
         del cls.singletons[runLoop]
+
     removeRunLoopStopperFromRunLoop_ = classmethod(removeRunLoopStopperFromRunLoop_)
 
     def stop(self):
@@ -114,11 +186,8 @@ def stopEventLoop():
             return True
         return False
     NSTimer.scheduledTimerWithTimeInterval_target_selector_userInfo_repeats_(
-        0.0,
-        stopper,
-        'performStop:',
-        None,
-        False)
+        0.0, stopper, "performStop:", None, False
+    )
     return True
 
 
@@ -127,19 +196,26 @@ def endSheetMethod(meth):
     Return a selector that can be used as the delegate callback for
     sheet methods
     """
-    return objc.selector(meth, signature=b'v@:@ii')
+    return objc.selector(
+        meth, signature=b"v@:@" + objc._C_NSInteger + objc._C_NSInteger
+    )
 
 
 def unexpectedErrorAlertPanel():
-    exceptionInfo = traceback.format_exception_only(
-        *sys.exc_info()[:2])[0].strip()
-    return NSRunAlertPanel("An unexpected error has occurred",
-            "%@",
-            "Continue", "Quit", None, "(%s)" % exceptionInfo)
+    exceptionInfo = traceback.format_exception_only(*sys.exc_info()[:2])[0].strip()
+    return NSRunAlertPanel(
+        "An unexpected error has occurred",
+        "%@",
+        "Continue",
+        "Quit",
+        None,
+        "(%s)" % exceptionInfo,
+    )
 
 
 def unexpectedErrorAlertPdb():
     import pdb
+
     traceback.print_exc()
     pdb.post_mortem(sys.exc_info()[2])
     return True
@@ -153,19 +229,20 @@ def machInterrupt(signum):
         NSApp().terminate_(None)
     else:
         import os
+
         os._exit(1)
 
 
 def installMachInterrupt():
-    try:
-        import signal
-        from PyObjCTools import MachSignals
-    except:
-        return
+    import signal
+    from PyObjCTools import MachSignals
+
     MachSignals.signal(signal.SIGINT, machInterrupt)
 
 
-def runConsoleEventLoop(argv=None, installInterrupt=False, mode=NSDefaultRunLoopMode):
+def runConsoleEventLoop(
+    argv=None, installInterrupt=False, mode=NSDefaultRunLoopMode, maxTimeout=3.0
+):
     if argv is None:
         argv = sys.argv
     if installInterrupt:
@@ -179,6 +256,10 @@ def runConsoleEventLoop(argv=None, installInterrupt=False, mode=NSDefaultRunLoop
             nextfire = runLoop.limitDateForMode_(mode)
             if not stopper.shouldRun():
                 break
+
+            soon = NSDate.dateWithTimeIntervalSinceNow_(maxTimeout)
+            if nextfire is not None:
+                nextfire = soon.earlierDate_(nextfire)
             if not runLoop.runMode_beforeDate_(mode, nextfire):
                 stopper.stop()
 
@@ -189,7 +270,13 @@ def runConsoleEventLoop(argv=None, installInterrupt=False, mode=NSDefaultRunLoop
 RAISETHESE = (SystemExit, MemoryError, KeyboardInterrupt)
 
 
-def runEventLoop(argv=None, unexpectedErrorAlert=None, installInterrupt=None, pdb=None, main=NSApplicationMain):
+def runEventLoop(
+    argv=None,
+    unexpectedErrorAlert=None,
+    installInterrupt=None,
+    pdb=None,
+    main=NSApplicationMain,
+):
     """Run the event loop, ask the user if we should continue if an
     exception is caught. Use this function instead of NSApplicationMain().
     """
@@ -197,19 +284,17 @@ def runEventLoop(argv=None, unexpectedErrorAlert=None, installInterrupt=None, pd
         argv = sys.argv
 
     if pdb is None:
-        pdb = 'USE_PDB' in os.environ
+        pdb = "USE_PDB" in os.environ
 
     if pdb:
         from PyObjCTools import Debugging
+
         Debugging.installVerboseExceptionHandler()
         # bring it to the front, starting from terminal
         # often won't
         activator = PyObjCAppHelperApplicationActivator.alloc().init()
         NSNotificationCenter.defaultCenter().addObserver_selector_name_object_(
-            activator,
-            'activateNow:',
-            NSApplicationDidFinishLaunchingNotification,
-            None,
+            activator, "activateNow:", NSApplicationDidFinishLaunchingNotification, None
         )
     else:
         Debugging = None
@@ -242,11 +327,12 @@ def runEventLoop(argv=None, unexpectedErrorAlert=None, installInterrupt=None, pd
             except RAISETHESE:
                 traceback.print_exc()
                 break
-            except:
+            except:  # noqa: E722, B001
                 exctype, e, tb = sys.exc_info()
-                objc_exception = False
                 if isinstance(e, objc.error):
-                    NSLog("%@", unicode(str(e), 'utf-8', 'replace'))
+                    error_str = str(e)
+
+                    NSLog("%@", error_str)
                 elif not unexpectedErrorAlert():
                     NSLog("%@", "An exception has occured:")
                     traceback.print_exc()
